<!DOCTYPE html>
{% load staticfiles %}
{% load lbutils %}
{% load compress %}
<html class="{% block html_class %}skin-blue{% endblock %}">
  <head>
    <meta charset="UTF-8"/>
    <title>
      {% block title %}{% get_setting "PROJECT_TITLE" %}{% endblock %}
    </title>
    <meta content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no' name='viewport'/>
    <link rel="shortcut icon" href="{% static 'img/favicon.ico' %}"/>
    <link href="{% static 'AdminLTE/bootstrap/css/bootstrap.min.css' %}" rel="stylesheet" type="text/css" />
      <script>
        LT_IE9 = false;
      </script>
    <!--[if lt IE 9]>
      <script>
        LT_IE9 = true;
      </script>
    <![endif]-->
    {% compress css %}
    <link href="{% static 'font-awesome/css/font-awesome.min.css' %}" rel="stylesheet" type="text/css" />
    <link href="{% static 'Ionicons/css/ionicons.min.css' %}" rel="stylesheet" type="text/css" />
    <link href="{% static 'AdminLTE/dist/css/AdminLTE.css' %}" rel="stylesheet" type="text/css" />
    <link href="{% static 'AdminLTE/dist/css/skins/_all-skins.min.css' %}" rel="stylesheet" type="text/css" />
    {% endcompress %}
    {% compress css %}
    <link href="{% static 'css/lbadminlte.css' %}" rel="stylesheet" type="text/css" />
    {% endcompress %}
    <!--[if lt IE 9]>
      <script src="{% static 'html5shiv/dist/html5shiv.min.js' %}"></script>
      <script src="{% static 'respond/dest/respond.min.js' %}"></script>
      <style>
        .hidden-lt-ie-9 {
          display: none;
        }
        .left-side {
          padding-top: 0px;
        }
      </style>
    <![endif]-->
    {% block head_ext %}
    {% endblock %}
  </head>
  <body class="{% block body_class %}skin-blue{% endblock %}">
    {% block body %} {% endblock %}
    {% block footer %} {% endblock %}
    <script type="text/javascript">
      var NEXT_URL = null;
      {% if request.GET.next %}
      NEXT_URL = "{{ request.GET.next }}";
      {% endif %}
      var NAV_SEL_NODE = "{% block nav_sel_node %}{{ nav_sel_node }}{% endblock %}";
      {% block js_vars %}
      var AUTO_INIT_DATEINPUT = true;
      {% endblock %}
    </script>
    <script src="{% static 'AdminLTE/plugins/jQuery/jquery-2.2.3.min.js' %}" type="text/javascript"></script>
    <script type="text/javascript">
      var NAV_SEL_NODE = $('#' + NAV_SEL_NODE);
      if (NAV_SEL_NODE.length) {
        NAV_SEL_NODE.addClass('active');
        NAV_SEL_NODE.parents('li.treeview').addClass('active');
      }
    </script>
    {% compress js %}
    <script src="{% static 'AdminLTE/bootstrap/js/bootstrap.min.js' %}" type="text/javascript"></script>
    <script src="{% static 'AdminLTE/dist/js/app.js' %}" type="text/javascript"></script>
    {% endcompress %}
    {% block footer_ext %} {% endblock %}
    {% compress js %}
    <script src="{% static 'js/lbadminlte.js' %}" type="text/javascript"></script>
    {% endcompress %}
  </body>
</html>
