{% extends "base.html" %}

{% block body %}
  <div style="margin: 10px;">
    <h1>403</h1>
    <div>
      No permission <a href="###" onclick="history.back()">Back</a>
    </div>
  </div>
{% endblock %}
